"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const ow_1 = __importDefault(require("ow"));
const Account_1 = require("../Account");
const Mutations_1 = require("./Mutations");
const RolesAuthModule_1 = require("./RolesAuthModule");
function constructMutations() {
    const setAccount = (state, payload) => {
        Account_1.Account.validate(payload);
        state.account = Object.assign({}, payload);
        RolesAuthModule_1.RolesAuthModule.State.validate(state);
    };
    const resetUser = (state) => {
        state.account = undefined;
        RolesAuthModule_1.RolesAuthModule.State.validate(state);
    };
    const setState = (state, payload) => {
        ow_1.default(payload, "payload", ow_1.default.object);
        ow_1.default(payload.state, "payload.state", ow_1.default.string.oneOf([RolesAuthModule_1.RolesAuthModule.AuthState.LOADING, RolesAuthModule_1.RolesAuthModule.AuthState.AUTHENTICATED, RolesAuthModule_1.RolesAuthModule.AuthState.NOTAUTHENTICATED]));
        state.state = payload.state;
        RolesAuthModule_1.RolesAuthModule.State.validate(state);
    };
    const setRole = (state, payload) => {
        ow_1.default(payload, "payload", ow_1.default.object);
        ow_1.default(payload.role, "payload.role", ow_1.default.string);
        ow_1.default(payload.hasRole, "payload.hasRole", ow_1.default.boolean);
        state.roles = Object.assign({}, state.roles, { [payload.role]: payload.hasRole });
        RolesAuthModule_1.RolesAuthModule.State.validate(state);
    };
    const setRoleRequest = (state, payload) => {
        ow_1.default(payload, "payload", ow_1.default.object);
        ow_1.default(payload.role, "payload.role", ow_1.default.string);
        ow_1.default(payload.isRequestingRole, "payload.isRequestingRole", ow_1.default.boolean);
        state.roleRequests = Object.assign({}, state.roles, { [payload.role]: payload.isRequestingRole });
        RolesAuthModule_1.RolesAuthModule.State.validate(state);
    };
    const mutations = {
        [Mutations_1.Mutations.SetAccount.name]: setAccount,
        [Mutations_1.Mutations.ResetUser.name]: resetUser,
        [Mutations_1.Mutations.SetState.name]: setState,
        [Mutations_1.Mutations.SetRole.name]: setRole,
        [Mutations_1.Mutations.SetRoleRequest.name]: setRoleRequest,
    };
    return mutations;
}
exports.constructMutations = constructMutations;
//# sourceMappingURL=impl_mutations.js.map